@@ -887,7 +887,8 @@ void Core::refreshProjectItem(const ObjectId &id)
             m_monitorManager->activateMonitor(Kdenlive::ClipMonitor);
             m_monitorManager->refreshClipMonitor(true);
         }
-        if (m_monitorManager->projectMonitorVisible() && m_mainWindow->getCurrentTimeline()->controller()->refreshIfVisible(id.itemId)) {
+        if (m_monitorManager->projectMonitorVisible() && m_mainWindow->getCurrentTimeline() &&
+            m_mainWindow->getCurrentTimeline()->controller()->refreshIfVisible(id.itemId)) {
             m_monitorManager->refreshTimer.start();
         }
         break;
@@ -1582,17 +1583,17 @@ void Core::groupAssetMultiKeyframeCommand(const ObjectId &id, const QString &ass
     }
 }
 
-void Core::removeGroupEffect(const ObjectId &id, const QString &assetId)
+void Core::removeGroupEffect(const ObjectId &id, const QString &assetId, int originalId)
 {
     switch (id.type) {
     case KdenliveObjectType::TimelineClip:
         if (auto tl = currentDoc()->getTimeline(id.uuid)) {
-            tl->removeEffectFromGroup(id.itemId, assetId);
+            tl->removeEffectFromGroup(id.itemId, assetId, originalId);
         }
         break;
     case KdenliveObjectType::BinClip:
         if (bin() != nullptr) {
-            bin()->removeEffectFromGroup(assetId);
+            bin()->removeEffectFromGroup(id.itemId, assetId, originalId);
         }
         break;
     default:
@@ -1641,3 +1642,10 @@ void Core::highlightFileInExplorer(QList<QUrl> urls)
         KIO::highlightInFileManager(urls);
     }
 }
+
+void Core::updateHoverItem(const QUuid &uuid)
+{
+    if (m_guiConstructed && uuid == m_mainWindow->getCurrentTimeline()->getUuid()) {
+        m_mainWindow->getCurrentTimeline()->regainFocus();
+    }
+}
