@@ -35,7 +35,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <profiles/profilemodel.hpp>
 
 ClipLoadTask::ClipLoadTask(const ObjectId &owner, const QDomElement &xml, bool thumbOnly, int in, int out, QObject *object)
-    : AbstractTask(owner, AbstractTask::LOADJOB, object)
+    : AbstractTask(owner, thumbOnly ? AbstractTask::THUMBJOB : AbstractTask::LOADJOB, object)
     , m_xml(xml)
     , m_in(in)
     , m_out(out)
@@ -49,11 +49,10 @@ ClipLoadTask::~ClipLoadTask() {}
 void ClipLoadTask::start(const ObjectId &owner, const QDomElement &xml, bool thumbOnly, int in, int out, QObject *object, bool force,
                          const std::function<void()> &readyCallBack)
 {
-    ClipLoadTask *task = new ClipLoadTask(owner, xml, thumbOnly, in, out, object);
     if (!thumbOnly && pCore->taskManager.hasPendingJob(owner, AbstractTask::LOADJOB)) {
-        delete task;
-        task = nullptr;
+        return;
     }
+    ClipLoadTask *task = new ClipLoadTask(owner, xml, thumbOnly, in, out, object);
     if (task) {
         // Otherwise, start a new load task thread.
         task->m_isForce = force;
@@ -223,7 +222,7 @@ void ClipLoadTask::generateThumbnail(std::shared_ptr<ProjectClip> binClip, std::
         QImage thumb = ThumbnailCache::get()->getThumbnail(binClip->hashForThumbs(), QString::number(m_owner.itemId), frameNumber);
         if (!thumb.isNull()) {
             // Thumbnail found in cache
-            qDebug() << "=== FOUND THUMB IN CACHe";
+            qDebug() << "=== FOUND THUMB IN CACHE";
             QMetaObject::invokeMethod(binClip.get(), "setThumbnail", Qt::QueuedConnection, Q_ARG(QImage, thumb), Q_ARG(int, m_in), Q_ARG(int, m_out),
                                       Q_ARG(bool, true));
         } else {
@@ -232,6 +231,15 @@ void ClipLoadTask::generateThumbnail(std::shared_ptr<ProjectClip> binClip, std::
             }
             std::unique_ptr<Mlt::Producer> thumbProd = binClip->getThumbProducer();
             if (thumbProd && thumbProd->is_valid()) {
+                if (binClip->clipType() != ClipType::Timeline && binClip->clipType() != ClipType::Playlist) {
+                    Mlt::Profile *prodProfile = &pCore->thumbProfile();
+                    Mlt::Filter scaler(*prodProfile, "swscale");
+                    Mlt::Filter padder(*prodProfile, "resize");
+                    Mlt::Filter converter(*prodProfile, "avcolor_space");
+                    thumbProd->attach(scaler);
+                    thumbProd->attach(padder);
+                    thumbProd->attach(converter);
+                }
                 if (frameNumber > 0) {
                     thumbProd->seek(frameNumber);
                 }
@@ -259,9 +267,10 @@ void ClipLoadTask::generateThumbnail(std::shared_ptr<ProjectClip> binClip, std::
                     } else if (binClip.get() && !m_isCanceled.loadAcquire()) {
                         // We don't follow m_isCanceled there,
                         qDebug() << "=== GOT THUMB FOR: " << m_in << "x" << m_out;
+                        ThumbnailCache::get()->storeThumbnail(QString::number(m_owner.itemId), frameNumber, result, false);
+                        m_progress = 100;
                         QMetaObject::invokeMethod(binClip.get(), "setThumbnail", Qt::QueuedConnection, Q_ARG(QImage, result), Q_ARG(int, m_in),
                                                   Q_ARG(int, m_out), Q_ARG(bool, false));
-                        ThumbnailCache::get()->storeThumbnail(QString::number(m_owner.itemId), frameNumber, result, false);
                     }
                 }
             }
@@ -278,6 +287,7 @@ void ClipLoadTask::run()
     }
     QMutexLocker lock(&m_runMutex);
     // QThread::currentThread()->setPriority(QThread::HighestPriority);
+    m_running = true;
     if (m_thumbOnly) {
         auto binClip = pCore->projectItemModel()->getClipByBinID(QString::number(m_owner.itemId));
         if (binClip && binClip->statusReady()) {
@@ -292,7 +302,6 @@ void ClipLoadTask::run()
         }
         return;
     }
-    m_running = true;
     Q_EMIT pCore->projectItemModel()->resetPlayOrLoopZone(QString::number(m_owner.itemId));
     QString resource = Xml::getXmlProperty(m_xml, QStringLiteral("resource"));
     qDebug() << "============STARTING LOAD TASK FOR: " << m_owner.itemId << " = " << resource << "\n\n:::::::::::::::::::";
@@ -734,7 +743,7 @@ void ClipLoadTask::run()
                 replaceName = true;
             }
             // Reset produccer to get rid of cached frame
-            QMutexLocker lock(&pCore->xmlMutex);
+            QReadLocker lock(&pCore->xmlMutex);
             producer.reset(new Mlt::Producer(pCore->getProjectProfile(), "xml-string", xmlData.constData()));
             lock.unlock();
             if (replaceProxy) {
@@ -749,6 +758,7 @@ void ClipLoadTask::run()
                 pCore->bin()->shouldCheckProfile = false;
                 QMetaObject::invokeMethod(pCore->bin(), "slotCheckProfile", Qt::QueuedConnection, Q_ARG(QString, QString::number(m_owner.itemId)));
             }
+            m_progress = 100;
             Q_EMIT taskDone();
             return;
         }
