@@ -10,6 +10,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "logger.hpp"
 #endif
 #include "dialogs/splash.hpp"
+#include "dialogs/wizard.h"
 #include <config-kdenlive.h>
 
 #include <mlt++/Mlt.h>
@@ -181,15 +182,10 @@ int main(int argc, char *argv[])
 
     aboutData.setDesktopFileName(QStringLiteral("org.kde.kdenlive"));
 
-    // Register about data
+    // Set application data
     KAboutData::setApplicationData(aboutData);
-
-    // Set app stuff from about data
-    app.setApplicationName(QStringLiteral("kdenlive"));
     app.setWindowIcon(QIcon(QStringLiteral(":/pics/kdenlive.png")));
-    app.setApplicationDisplayName(aboutData.displayName());
-    app.setOrganizationDomain(aboutData.organizationDomain());
-    app.setApplicationVersion(aboutData.version());
+
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
 
     qApp->processEvents(QEventLoop::AllEvents);
@@ -197,7 +193,6 @@ int main(int argc, char *argv[])
     // Create command line parser with options
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
-    parser.setApplicationDescription(aboutData.shortDescription());
 
     // config option is processed in KConfig (src/core/kconfig.cpp)
     parser.addOption(QCommandLineOption(QStringLiteral("config"), i18n("Set a custom config file name."), QStringLiteral("config file")));
@@ -271,6 +266,9 @@ int main(int argc, char *argv[])
         pCore->initHeadless(url);
         app.processEvents();
 
+        // ensure we have a proper kdenlive_render path, particular important for AppImage
+        Wizard::fixKdenliveRenderPath();
+
         RenderRequest *renderrequest = new RenderRequest();
         renderrequest->setOutputFile(renderUrl.toLocalFile());
         renderrequest->loadPresetParams(presetName);
@@ -404,21 +402,6 @@ int main(int argc, char *argv[])
 
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup grp(config, "unmanaged");
-    if (!grp.exists()) {
-        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-        if (env.value(QStringLiteral("XDG_CURRENT_DESKTOP")).toLower() == QLatin1String("kde") && packageType != QStringLiteral("appimage")) {
-            qCDebug(KDENLIVE_LOG) << "KDE Desktop detected and not Appimage, using system icons";
-        } else {
-            // We are not on a KDE desktop or in an Appimage, force breeze icon theme
-            // Check if breeze theme is available
-            QStringList iconThemes = KIconTheme::list();
-            if (iconThemes.contains(QStringLiteral("breeze"))) {
-                grp.writeEntry("force_breeze", true);
-                grp.writeEntry("use_dark_breeze", true);
-                qCDebug(KDENLIVE_LOG) << "Non KDE Desktop or Appimage detected, forcing Breeze icon theme";
-            }
-        }
-    }
     KConfigGroup uicg(config, "UiSettings");
     if (!uicg.exists()) {
         uicg.writeEntry("ColorSchemePath", "BreezeDark.colors");
@@ -430,15 +413,12 @@ int main(int argc, char *argv[])
     KDBusService programDBusService;
 #endif
     bool forceBreeze = grp.readEntry("force_breeze", QVariant(false)).toBool();
-    if (forceBreeze) {
-        bool darkBreeze = grp.readEntry("use_dark_breeze", QVariant(false)).toBool();
-        QIcon::setThemeName(darkBreeze ? QStringLiteral("breeze-dark") : QStringLiteral("breeze"));
+    if (forceBreeze || packageType == QLatin1String("appimage")) {
+        QIcon::setThemeName(QStringLiteral("breeze"));
     }
     qApp->processEvents(QEventLoop::AllEvents);
 
-#ifdef USE_DRMINGW
-    ExcHndlInit();
-#elif defined(KF5_USE_CRASH)
+#if defined(KF5_USE_CRASH)
     KCrash::initialize();
 #endif
 
@@ -478,7 +458,9 @@ int main(int argc, char *argv[])
         // App is crashing, delete config files and restart
         result = EXIT_CLEAN_RESTART;
     } else {
-        QObject::connect(pCore.get(), &Core::loadingMessageUpdated, &splash, &Splash::showProgressMessage, Qt::DirectConnection);
+        QObject::connect(pCore.get(), &Core::loadingMessageNewStage, &splash, &Splash::showProgressMessage, Qt::DirectConnection);
+        QObject::connect(pCore.get(), &Core::loadingMessageIncrease, &splash, &Splash::increaseProgressMessage, Qt::DirectConnection);
+        QObject::connect(pCore.get(), &Core::loadingMessageHide, &splash, &Splash::clearMessage, Qt::DirectConnection);
         QObject::connect(pCore.get(), &Core::closeSplash, &splash, [&]() { splash.finish(pCore->window()); });
         pCore->initGUI(inSandbox, parser.value(mltPathOption), url, clipsToLoad);
         result = app.exec();
