@@ -99,7 +99,7 @@ public:
     void applyClipAssetGroupMultiKeyframeCommand(int cid, const QString &assetId, const QList<QModelIndex> &indexes, GenTime pos,
                                                  const QStringList &sourceValues, const QStringList &values, QUndoCommand *command);
     QList<std::shared_ptr<KeyframeModelList>> getGroupKeyframeModels(int cid, const QString &assetId);
-    void removeEffectFromGroup(int cid, const QString &assetId);
+    void removeEffectFromGroup(int cid, const QString &assetId, int originalId);
     void disableEffectFromGroup(int cid, const QString &assetId, bool disable, Fun &undo, Fun &redo);
 
     const QString groupsData();
@@ -110,6 +110,7 @@ public:
 
     /** @brief Rebuild track compositing */
     void buildTrackCompositing(bool rebuild = false) override;
+    void removeTrackCompositing() override;
     /** @brief Register all tracks in the mixer */
     void rebuildMixer();
     void _beginRemoveRows(const QModelIndex & /*unused*/, int /*unused*/, int /*unused*/) override;
